from algora.common.base_enum import BaseEnum


class BacktestEventType(BaseEnum):
    PORTFOLIO = 'PORTFOLIO'
    CASH_PAYMENT = 'CASH_PAYMENT'
